@@ -4,12 +4,12 @@ from typing import Any, Self
 import numpy as np
 import pandas as pd
 from docx.document import Document
-from docx.enum.table import WD_ALIGN_VERTICAL
+from docx.enum.table import WD_ALIGN_VERTICAL, WD_TABLE_ALIGNMENT
 from docx.enum.text import WD_ALIGN_PARAGRAPH
 from docx.oxml import OxmlElement, parse_xml
 from docx.oxml.ns import nsdecls, qn
 from docx.shared import Inches, Pt, RGBColor
-from docx.table import Table
+from docx.table import Table as TableDocx
 from docx.table import _Cell as TableCell
 from yaml import MappingNode
 
@@ -69,7 +69,7 @@ def _style_horizontal_blocks_header(cell: TableCell):
     cell.paragraphs[0].runs[0].font.size = Pt(12)
 
 
-def _horizontal_blocks_header(columns: pd.MultiIndex, table_docx: Table):
+def _horizontal_blocks_header(columns: pd.MultiIndex, table_docx: TableDocx):
     column_counter: int = 1
     blocks: list[str] = list(columns.get_level_values(level=0).unique())
     for block in blocks:
@@ -92,7 +92,7 @@ def _style_column_names(cell: TableCell):
 
 
 def _fill_column_names(
-    table: pd.DataFrame, table_docx: Table, horizontal: bool
+    table: pd.DataFrame, table_docx: TableDocx, horizontal: bool
 ):
     if horizontal:
         start_row: int = 1
@@ -115,13 +115,13 @@ def _style_index_names(cell: TableCell):
 
 
 def _fill_index_names(
-    index: pd.Index | pd.MultiIndex, table_docx: Table, horizontal: bool
+    index: pd.Index | pd.MultiIndex, table_docx: TableDocx, horizontal: bool
 ):
     start_row: int = 2 if horizontal else 1
 
     index_names: pd.Index = (
         index
-        if (horizontal or isinstance(index, pd.Index))
+        if (horizontal or (not isinstance(index, pd.MultiIndex)))
         else index.get_level_values(level=1)
     )
 
@@ -132,7 +132,7 @@ def _fill_index_names(
 
 
 # we only separate blocks in vertically stacked tables
-def _separate_blocks(index: pd.MultiIndex, table_docx: Table):
+def _separate_blocks(index: pd.MultiIndex, table_docx: TableDocx):
     blocks: list[str] = list(index.get_level_values(level=0).unique())
     previous_rows = 0
     for block in blocks[:-1]:
@@ -186,7 +186,7 @@ def _fill_content(
     table: pd.DataFrame,
     color_table: pd.DataFrame,
     shade_table: pd.DataFrame,
-    table_docx: Table,
+    table_docx: TableDocx,
     horizontal: bool,
 ):
     start_row: int = 2 if horizontal else 1
@@ -209,7 +209,7 @@ def _fill_content(
         _style_content(cell)
 
 
-def _style_table(table_docx: Table):
+def _style_table(table_docx: TableDocx):
     table_docx.style = RENDER_CONFIG.get("style", None)
     table_docx.autofit = RENDER_CONFIG["autofit"]
 
@@ -221,10 +221,10 @@ def render_table(
     document: Document,
     block_sep: bool,
     **kwargs,
-) -> Table:
+) -> TableDocx:
 
     horizontal: bool = isinstance(table.columns, pd.MultiIndex)
-    table_docx: Table = document.add_table(
+    table_docx: TableDocx = document.add_table(
         rows=len(table.index) + table.columns.nlevels,
         cols=len(table.columns) + 1,
     )
@@ -237,6 +237,7 @@ def render_table(
     if block_sep:
         _separate_blocks(table.index, table_docx)
     _fill_content(table, color_table, shade_table, table_docx, horizontal)
+    table_docx.alignment = WD_TABLE_ALIGNMENT.CENTER
     return document
 
 
@@ -274,7 +275,15 @@ class Table:
         table_cfg: dict[str, Any] = loader.construct_mapping(node, deep=True)
         root_path: Path = loader.imports["table"]
         file_prefix: str = table_cfg.pop("id")
-        data_file: Path = root_path / f"{file_prefix}_data.feather"
+
+        # the data file has an optional "_data" suffix
+        # if a file with the suffix exists, it will be preferred
+        data_file_suffix: Path = root_path / f"{file_prefix}_data.feather"
+        if data_file_suffix.exists():
+            data_file: Path = data_file_suffix
+        else:
+            data_file: Path = root_path / f"{file_prefix}.feather"
+
         color_file: Path = root_path / f"{file_prefix}_color.feather"
         shade_file: Path = root_path / f"{file_prefix}_shade.feather"
         return cls(
